package chapter3_streams.collections;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.function.Predicate;

import chapter3_streams.Gender;
import chapter3_streams.Person;

/**
 * Beispielprogramm zur Demonstration von komplexeren Bedingungen mit Prdikaten.
 * 
 * @author Michael Inden
 * 
 * Copyright 2014 by Michael Inden 
 */
public class ComplexPredicatesExample 
{
	public static void main(final String[] args)
	{
		final List<Person> persons = createDemoData();
		
		// Einfache Prdikate formulieren
		final Predicate<Person> isAdult = person -> person.getAge() >= 18;
		final Predicate<Person> isMale = person -> person.getGender() == Gender.MALE;
	
		// Negation einzelner Prdikate
		final Predicate<Person> isYoung = isAdult.negate();
		final Predicate<Person> isFemale = isMale.negate();
		
		// Kombination von Prdikaten mit AND
		final Predicate<Person> boys = isMale.and(isYoung);
		final Predicate<Person> women = isFemale.and(isAdult);
		
		// Kombination von Prdikaten mit OR
		final Predicate<Person> boysOrWomen = boys.or(women);
		
		removeAll(persons, boysOrWomen);
		System.out.println(persons);
	}
	
	private static List<Person> createDemoData() {
		final List<Person> persons = new ArrayList<>();
		persons.add(new Person("Michael", 43));
		persons.add(new Person("Barbara", 41, Gender.FEMALE));
		persons.add(new Person("Lili", 34, Gender.FEMALE));
		persons.add(new Person("Mona Lisa", 17, Gender.FEMALE));
		persons.add(new Person("Tom", 8));
		persons.add(new Person("Bjrn", 7));
		return persons;
	}

	// Externe Iteration 
	private static <E> void removeAll(final List<E> list, 
				 	                  final Predicate<? super E> condition) 
	{
		final Iterator<E> it = list.iterator();
		while (it.hasNext()) 
		{
			if (condition.test(it.next())) {
				it.remove();
			}
		}
	}
}